DockPane Example
===============================================================================

:download:`dock_pane.enaml <../../../examples/widgets/dock_pane.enaml>`

.. literalinclude:: ../../../examples/widgets/dock_pane.enaml
    :language: python

::

 $ enaml-run dock_pane.enaml

.. image:: images/dock_pane.png
